import { ConfigParams, ConfigResult } from './ConfigService';
import { ComposeParams } from './ComposeService';
import { RunParams } from './RunService';
import { ConfigPreset } from '../model';
export declare type StartParams = ConfigParams & ComposeParams & RunParams;
/**
 * Main entry point for API integration.
 */
export declare class BootstrapService {
    private readonly root;
    constructor(root?: string);
    /**
     * It generates the configuration and nemesis for the provided preset
     *
     * @param config the params of the config command.
     */
    config(config?: ConfigParams): Promise<ConfigResult>;
    /**
     * It generates the docker-compose.yaml file from the previously generated configuration.
     *
     * The config method/command needs to be called before this method
     *
     * @param config the params of the compose command.
     * @param passedPresetData the created preset if you know if, otherwise will load the latest one resolved from the target folder.
     */
    compose(config?: ComposeParams, passedPresetData?: ConfigPreset): Promise<void>;
    /**
     * It boots the network via docker using the generated docker-compose.yml file and configuration
     *
     * The config and compose methods/commands need to be called before this method.
     *
     * This is just a wrapper for docker-compose up bash call.
     *
     * @param config the params of the run command.
     */
    run(config?: RunParams): Promise<void>;
    /**
     * This method aggregates config, compose and run all in one.
     *
     * @param config the aggregated params in order to run all the sub commands.
     */
    start(config: StartParams): Promise<ConfigResult>;
    /**
     * It stops the docker-compose network if running.
     *
     * This is just a wrapper for docker-compose down bash call.
     *
     * @param config the params necessary to detect and stop the network.
     */
    stop(config?: RunParams): Promise<void>;
}
