"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BootstrapService = void 0;
const ConfigService_1 = require("./ConfigService");
const ComposeService_1 = require("./ComposeService");
const RunService_1 = require("./RunService");
const BootstrapUtils_1 = require("./BootstrapUtils");
/**
 * Main entry point for API integration.
 */
class BootstrapService {
    constructor(root = './node_modules/symbol-bootstrap') {
        this.root = root;
    }
    /**
     * It generates the configuration and nemesis for the provided preset
     *
     * @param config the params of the config command.
     */
    async config(config = ConfigService_1.ConfigService.defaultParams) {
        return new ConfigService_1.ConfigService(this.root, config).run();
    }
    /**
     * It generates the docker-compose.yaml file from the previously generated configuration.
     *
     * The config method/command needs to be called before this method
     *
     * @param config the params of the compose command.
     * @param passedPresetData the created preset if you know if, otherwise will load the latest one resolved from the target folder.
     */
    async compose(config = ComposeService_1.ComposeService.defaultParams, passedPresetData) {
        await new ComposeService_1.ComposeService(this.root, config).run(passedPresetData);
    }
    /**
     * It boots the network via docker using the generated docker-compose.yml file and configuration
     *
     * The config and compose methods/commands need to be called before this method.
     *
     * This is just a wrapper for docker-compose up bash call.
     *
     * @param config the params of the run command.
     */
    async run(config = RunService_1.RunService.defaultParams) {
        await new RunService_1.RunService(config).run();
    }
    /**
     * This method aggregates config, compose and run all in one.
     *
     * @param config the aggregated params in order to run all the sub commands.
     */
    async start(config) {
        if (config.reset) {
            BootstrapUtils_1.BootstrapUtils.deleteFolder(config.target);
        }
        const configResult = await this.config(config);
        await this.compose(config, configResult.presetData);
        await this.run(config);
        return configResult;
    }
    /**
     * It stops the docker-compose network if running.
     *
     * This is just a wrapper for docker-compose down bash call.
     *
     * @param config the params necessary to detect and stop the network.
     */
    async stop(config = RunService_1.RunService.defaultParams) {
        await new RunService_1.RunService(config).stop();
    }
}
exports.BootstrapService = BootstrapService;
